@@ -1,7 +1,7 @@
 /**************************************************************************
  *   browser.c  --  This file is part of GNU nano.                        *
  *                                                                        *
- *   Copyright (C) 2001-2011, 2013-2024 Free Software Foundation, Inc.    *
+ *   Copyright (C) 2001-2011, 2013-2025 Free Software Foundation, Inc.    *
  *   Copyright (C) 2015-2016, 2020, 2022 Benno Schulenberg                *
  *                                                                        *
  *   GNU nano is free software: you can redistribute it and/or modify     *
@@ -483,14 +483,7 @@ char *browse(char *path)
 				continue;
 		}
 #endif /* ENABLE_MOUSE */
-#ifndef NANO_TINY
-		while (bracketed_paste)
-			kbinput = get_kbinput(midwin, BLIND);
-		if (kbinput == BRACKETED_PASTE_MARKER) {
-			beep();
-			continue;
-		}
-#endif
+
 		function = interpret(kbinput);
 
 		if (function == do_help || function == full_refresh) {
@@ -641,6 +634,10 @@ char *browse(char *path)
 			implant(first_sc_for(MBROWSER, function)->expansion);
 #endif
 #ifndef NANO_TINY
+		} else if (kbinput == START_OF_PASTE) {
+			while (get_kbinput(midwin, BLIND) != END_OF_PASTE)
+				;
+			statusline(AHEM, _("Paste is ignored"));
 		} else if (kbinput == THE_WINDOW_RESIZED) {
 			;  /* Gets handled below. */
 #endif
