@@ -1,8 +1,8 @@
 /**************************************************************************
  *   chars.c  --  This file is part of GNU nano.                          *
  *                                                                        *
- *   Copyright (C) 2001-2011, 2013-2021 Free Software Foundation, Inc.    *
- *   Copyright (C) 2016-2020 Benno Schulenberg                            *
+ *   Copyright (C) 2001-2011, 2013-2025 Free Software Foundation, Inc.    *
+ *   Copyright (C) 2016-2021 Benno Schulenberg                            *
  *                                                                        *
  *   GNU nano is free software: you can redistribute it and/or modify     *
  *   it under the terms of the GNU General Public License as published    *
@@ -98,10 +98,10 @@ bool is_blank_char(const char *c)
 bool is_cntrl_char(const char *c)
 {
 #ifdef ENABLE_UTF8
-	if (use_utf8) {
+	if (use_utf8)
 		return ((c[0] & 0xE0) == 0 || c[0] == DEL_CODE ||
 				((signed char)c[0] == -62 && (signed char)c[1] < -96));
-	} else
+	else
 #endif
 		return ((*c & 0x60) == 0 || *c == DEL_CODE);
 }
@@ -181,8 +181,8 @@ char control_mbrep(const char *c, bool isdata)
 int mbtowide(wchar_t *wc, const char *c)
 {
 	if ((signed char)*c < 0 && use_utf8) {
-		unsigned char v1 = (unsigned char)c[0];
-		unsigned char v2 = (unsigned char)c[1] ^ 0x80;
+		unsigned char v1 = c[0];
+		unsigned char v2 = c[1] ^ 0x80;
 
 		if (v2 > 0x3F || v1 < 0xC2)
 			return -1;
@@ -192,7 +192,7 @@ int mbtowide(wchar_t *wc, const char *c)
 			return 2;
 		}
 
-		unsigned char v3 = (unsigned char)c[2] ^ 0x80;
+		unsigned char v3 = c[2] ^ 0x80;
 
 		if (v3 > 0x3F)
 			return -1;
@@ -206,7 +206,7 @@ int mbtowide(wchar_t *wc, const char *c)
 				return -1;
 		}
 
-		unsigned char v4 = (unsigned char)c[3] ^ 0x80;
+		unsigned char v4 = c[3] ^ 0x80;
 
 		if (v4 > 0x3F || v1 > 0xF4)
 			return -1;
@@ -265,8 +265,8 @@ int char_length(const char *pointer)
 {
 #ifdef ENABLE_UTF8
 	if ((unsigned char)*pointer > 0xC1 && use_utf8) {
-		unsigned char c1 = (unsigned char)pointer[0];
-		unsigned char c2 = (unsigned char)pointer[1];
+		unsigned char c1 = pointer[0];
+		unsigned char c2 = pointer[1];
 
 		if ((c2 ^ 0x80) > 0x3F)
 			return 1;
@@ -644,7 +644,7 @@ bool has_blank_char(const char *string)
 
 	return *string;
 }
-#endif /* ENABLE_NANORC && (!NANO_TINY || ENABLE_JUSTIFY) */
+#endif
 
 /* Return TRUE when the given string is empty or consists of only blanks. */
 bool white_string(const char *string)
@@ -654,3 +654,12 @@ bool white_string(const char *string)
 
 	return !*string;
 }
+
+#if defined(ENABLE_SPELLER) || defined(ENABLE_COLOR)
+/* Remove leading whitespace from the given string. */
+void strip_leading_blanks_from(char *string)
+{
+	while (string && (*string == ' ' || *string == '\t'))
+		memmove(string, string + 1, strlen(string));
+}
+#endif
