@@ -1,7 +1,7 @@
 /**************************************************************************
  *   definitions.h  --  This file is part of GNU nano.                    *
  *                                                                        *
- *   Copyright (C) 1999-2011, 2013-2024 Free Software Foundation, Inc.    *
+ *   Copyright (C) 1999-2011, 2013-2025 Free Software Foundation, Inc.    *
  *   Copyright (C) 2014-2017 Benno Schulenberg                            *
  *                                                                        *
  *   GNU nano is free software: you can redistribute it and/or modify     *
@@ -205,8 +205,6 @@
 #define SHIFT_ALT_RIGHT  0x432
 #define SHIFT_ALT_UP     0x433
 #define SHIFT_ALT_DOWN   0x434
-//#define SHIFT_LEFT 0x451
-//#define SHIFT_RIGHT 0x452
 #define SHIFT_UP        0x453
 #define SHIFT_DOWN      0x454
 #define SHIFT_HOME      0x455
@@ -216,16 +214,20 @@
 #define SHIFT_DELETE    0x45D
 #define SHIFT_TAB       0x45F
 
-#define FOCUS_IN	0x491
-#define FOCUS_OUT	0x499
+#define FOCUS_IN   0x491
+#define FOCUS_OUT  0x499
+
+/* Custom keycodes for signaling the start and end of a bracketed paste. */
+#define START_OF_PASTE  0x4B5
+#define END_OF_PASTE    0x4BE
 
 /* Special keycodes for when a string bind has been partially implanted
  * or has an unpaired opening brace, or when a function in a string bind
  * needs execution or a specified function name is invalid. */
-#define MORE_PLANTS       0x4EA
-#define MISSING_BRACE     0x4EB
-#define PLANTED_A_COMMAND 0x4EC
-#define NO_SUCH_FUNCTION  0x4EF
+#define MORE_PLANTS        0x4EA
+#define MISSING_BRACE      0x4EB
+#define PLANTED_A_COMMAND  0x4EC
+#define NO_SUCH_FUNCTION   0x4EF
 
 #ifndef NANO_TINY
 /* A special keycode for Ctrl + the central key on the numeric keypad. */
@@ -235,9 +237,6 @@
 #define THE_WINDOW_RESIZED  0x4F7
 #endif
 
-/* A special keycode to signal the beginning and end of a bracketed paste. */
-#define BRACKETED_PASTE_MARKER  0x4FB
-
 /* A special keycode for when a key produces an unknown escape sequence. */
 #define FOREIGN_SEQUENCE  0x4FC
 
